@@ -134,10 +134,7 @@ class Formatter:
         i = 0
         while i < len(self.__tokens):
             token = self.__tokens[i]
-            if token.get_token_type() == TokenType.COMMENT \
-                    and token.get_value().startswith('/**'):
-                token.set_fixed_value(Formatter.__fix_links(self.__tokens[i].get_value()))
-            elif token.get_value() in ('def', 'package', 'class', 'trait', 'object'):
+            if token.get_value() in ('def', 'package', 'class', 'trait', 'object'):
                 pos = self.__find_comment_before(i)
                 comment = None
                 if pos != -1:
@@ -645,24 +642,25 @@ class Formatter:
         return extends
 
     @staticmethod
-    def __fix_links(comment):
+    def __fix_links(comment, namings_to_fix):
         i = 0
         while i < len(comment):
             if comment[i] == '[' and comment[i + 1] == '[':
                 link_start = i + 1
                 link_end = comment.find(i + 1, ']')
                 link = comment[link_start + 1:link_end]
-                comment = comment[:link_start] + Formatter.__fix_link(link) + comment[link_end:]
+                comment = comment[:link_start] + Formatter.__fix_link(link, namings_to_fix) + comment[link_end:]
                 i = link_end
             i += 1
         return comment
 
     @staticmethod
-    def __fix_link(link):
+    def __fix_link(link, namings_to_fix):
         components = link.split('.')
-        components = [Formatter.snake_to_lower_camel_case(component) if Formatter.__is_not_lower_camel_case(
-            component) else component for component in components]
-        components[-1] = components[-1].title()
+        i = 0
+        while i < len(components):
+            if components[i] in namings_to_fix:
+                components[i] = namings_to_fix[components[i]]
         return '.'.join(components)
 
     def __skip_ws_tokens(self, pos):
@@ -758,4 +756,6 @@ class Formatter:
                     token.set_fixed_value(namings_to_fix[token.get_value()])
             elif token.get_token_type() == TokenType.ANNOTATION and token.get_value()[1:] in namings_to_fix.keys():
                 token.set_fixed_value('@' + namings_to_fix[token.get_value()[1:]])
+            elif token.get_token_type() == TokenType.COMMENT and token.get_value().startswith('/**'):
+                token.set_fixed_value(Formatter.__fix_links(self.__tokens[i].get_value(), namings_to_fix))
             i += 1
